@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use File::Temp qw( tempdir );
 use Database::Migrator::Types qw( ClassName Dir File Str );
@@ -85,6 +85,7 @@ sub _write_ddl_file {
     print {$fh} $ddl
         or die $!;
     close $fh;
+    return;
 }
 
 sub _check_initial_database {
@@ -99,11 +100,7 @@ sub _check_initial_database {
         $self->database() . ' exists'
     );
 
-    is_deeply(
-        [ $self->_tables() ],
-        [qw( applied_migration foo )],
-        'newly created schema has the expected tables'
-    );
+    return;
 }
 
 sub _schema_ddl {
@@ -127,24 +124,6 @@ sub _test_migrations {
 
     $self->_new_migrator()->create_or_update_database();
 
-    is_deeply(
-        [ $self->_tables() ],
-        [qw( applied_migration bar baz foo )],
-        'migrated schema has the expected tables'
-    );
-
-    is_deeply(
-        [ $self->_indexes_on('bar') ],
-        ['bar_bar_name'],
-        'bar table has the expected indexes'
-    );
-
-    is_deeply(
-        [ $self->_indexes_on('baz') ],
-        ['baz_baz_name'],
-        'baz table has the expected indexes'
-    );
-
     my $migrations = $self->_dbh()
         ->selectcol_arrayref('SELECT migration FROM applied_migration') || [];
 
@@ -162,6 +141,50 @@ sub _test_migrations {
         undef,
         'no error running migrator again after migrations have been applied'
     );
+
+    $self->_write_perl_sub_migration;
+
+    $self->_new_migrator->create_or_update_database;
+
+    $migrations
+        = $self->_dbh->selectcol_arrayref(
+        'SELECT migration FROM applied_migration')
+        || [];
+
+    is_deeply(
+        $migrations,
+        [
+            '01-first',
+            '02-second',
+            '03-third',
+        ],
+        'migrations were recorded in the applied_migration table'
+    );
+
+    $self->_write_perl_program_migration;
+
+    like(
+        exception { $self->_new_migrator->create_or_update_database },
+        qr/Use of uninitialized/,
+        'perl program as migration threw exception due to warning',
+    );
+
+    $migrations
+        = $self->_dbh->selectcol_arrayref(
+        'SELECT migration FROM applied_migration')
+        || [];
+
+    is_deeply(
+        $migrations,
+        [
+            '01-first',
+            '02-second',
+            '03-third',
+        ],
+        'migrations were recorded in the applied_migration table'
+    );
+
+    return;
 }
 
 # This migration writes out two separate files to test that the files in a
@@ -217,6 +240,68 @@ EOF
     return;
 }
 
+sub _write_perl_sub_migration {
+    my $self = shift;
+
+    my $dir = $self->_migrations_dir->subdir('03-third');
+    $dir->mkpath;
+
+    my $file = $dir->file('migrate.pl'),
+
+        my $migration = <<'EOF';
+use strict;
+use warnings;
+
+sub {
+    my ($migrator) = @_;
+    my $sql = 'CREATE TABLE myperlsub (id INTEGER)';
+    $migrator->dbh->do($sql);
+    return;
+}
+EOF
+
+    $self->_write_ddl_file(
+        $file,
+        $migration,
+    );
+
+    return;
+}
+
+# This program generates a warning and so causes a failure.
+sub _write_perl_program_migration {
+    my $self = shift;
+
+    my $dir = $self->_migrations_dir->subdir('04-fourth');
+    $dir->mkpath;
+
+    my $file = $dir->file('migrate.pl'),
+
+        my $migration = <<'EOF';
+#!/usr/bin/env perl
+
+use strict;
+use warnings;
+
+sub main {
+    my $x;
+    print "hello $x\n";
+    return 1;
+}
+
+exit(main() ? 0 : 1);
+EOF
+
+    $self->_write_ddl_file(
+        $file,
+        $migration,
+    );
+
+    chmod 0755, $file->stringify;
+
+    return;
+}
+
 sub _new_migrator {
     my $self = shift;
 
